Miao
=============================

Print a cat, a simple exercise to train me to create python packages

To use::

	pip install miao

	import miao
	miao.Meow()

	or:

	from miao import Meow
	Meow()

----

The cat::

	 /\_/\
	( °Y° )
	
----